@@ -723,7 +723,7 @@ Note that this is a platform-independent method of activating IME
 
   resources.append(
       SessionResource('/session/:sessionId/frame').
-      Post('''Change focus to another frame on the page. If the frame ID is \
+      Post('''Change focus to another frame on the page. If the frame `id` is \
 `null`, the server
 should switch to the page's default content.''').
       AddJsonParameter('id', '{string|number|null|WebElement JSON Object}',
@@ -766,7 +766,9 @@ relative to the upper left corner of the screen.').
       
   resources.append(
       SessionResource('/session/:sessionId/window/:windowHandle/maximize').
-      Post('''Maximize the currently selected window if not already maximized.''').
+      Post('''Maximize the specified window if not already maximized. If the \
+:windowHandle URL parameter is "current", the currently active window will be \
+maximized.''').
       AddError('NoSuchWindow', 'If the specified window cannot be found.'))
 
   resources.append(
